pub struct Frame {
pub data: Vec<u8>,
}Expand description
An Ethernet Frame.
Remarks
This subscribable type is equivalent to an owned packet buffer. Internally, packet data remains in memory pool-allocated DPDK message buffers for as long as possible, before it is copied into a heap buffer to transfer ownership to the callback on a filter match. The DPDK message buffers are then freed back to the memory pool.
Fields
data: Vec<u8>Trait Implementations
Sourceimpl Subscribable for Frame
impl Subscribable for Frame
type Tracked = TrackedFrame
Sourcefn parsers() -> Vec<ConnParser>
fn parsers() -> Vec<ConnParser>
Returns a list of protocol parsers required to parse the subscribable type.
Sourcefn process_packet(
mbuf: Mbuf,
subscription: &Subscription<'_, Self>,
conn_tracker: &mut ConnTracker<Self::Tracked>,
)
fn process_packet( mbuf: Mbuf, subscription: &Subscription<'_, Self>, conn_tracker: &mut ConnTracker<Self::Tracked>, )
Process a single incoming packet.